### Name: aidsElas
### Title: Elasticities of the AIDS model
### Aliases: aidsElas elas.aidsEst print.aidsElas
### Keywords: models

### ** Examples

## Not run: 
##D    data( Blanciforti86 )
##D    # Data on food consumption are available only for the first 32 years
##D    Blanciforti86 <- Blanciforti86[ 1:32, ]
##D 
##D    estResult <- aidsEst( c( "pFood1", "pFood2", "pFood3", "pFood4" ),
##D       c( "wFood1", "wFood2", "wFood3", "wFood4" ), "xFood",
##D       data = Blanciforti86 )
##D    wMeans <- colMeans( Blanciforti86[ , c( "wFood1", "wFood2",
##D       "wFood3", "wFood4" ) ] )
##D    aidsElas( estResult$coef, shares = wMeans, method = "Ch",
##D       priceIndex = "S" )
##D 
##D    ## Repeating the evaluation of different elasticity formulas of
##D    ## Green & Alston (1990)
##D    priceNames <- c( "pFood1", "pFood2", "pFood3", "pFood4" )
##D    shareNames <- c( "wFood1", "wFood2", "wFood3", "wFood4" )
##D 
##D    # AIDS estimation and elasticities
##D    estResultA <- aidsEst( priceNames, shareNames, "xFood",
##D       data = Blanciforti86[ -1, ],
##D       method = "IL", maxiter = 100 )
##D    diag( elas( estResultA, method = "AIDS" )$marshall )
##D 
##D    # LA-AIDS estimation
##D    estResultLA <- aidsEst( priceNames, shareNames, "xFood",
##D       data = Blanciforti86, priceIndex = "SL", maxiter = 100 )
##D 
##D    # LA-AIDS + formula of AIDS
##D    diag( elas( estResultLA, method = "AIDS" )$marshall )
##D 
##D    # LA-AIDS + formula of Eales + Unnevehr
##D    diag( elas( estResultLA, method = "EU" )$marshall )
##D 
##D    # LA-AIDS + formula of Goddard or Chalfant:
##D    diag( elas( estResultLA, method = "Go" )$marshall )
##D    diag( elas( estResultLA, method = "Ch" )$marshall )
##D 
##D    # LA-AIDS + formula of Green + Alston (= 1st of Buse):
##D    diag( elas( estResultLA, method = "GA" )$marshall )
## End(Not run)



